@@ -20,7 +20,9 @@ from io import StringIO
 from logging import getLogger
 from threading import Lock
 from time import strptime
+from types import TracebackType
 from typing import Any, Callable, Generator, Iterable, NamedTuple, Sequence
+from uuid import UUID
 
 from . import errors, proxy
 from .auth import (
@@ -97,7 +99,7 @@ DEFAULT_CLIENT_PREFETCH_THREADS = 4
 MAX_CLIENT_PREFETCH_THREADS = 10
 
 
-def DefaultConverterClass():
+def DefaultConverterClass() -> type:
     if IS_WINDOWS:
         from .converter_issue23517 import SnowflakeConverterIssue23517
 
@@ -267,7 +269,7 @@ class SnowflakeConnection:
 
     OCSP_ENV_LOCK = Lock()
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         self._lock_sequence_counter = Lock()
         self.sequence_counter = 0
         self._errorhandler = Error.default_errorhandler
@@ -305,7 +307,7 @@ class SnowflakeConnection:
         # get the imported modules from sys.modules
         self._log_telemetry_imported_packages()
 
-    def __del__(self):  # pragma: no cover
+    def __del__(self) -> None:  # pragma: no cover
         try:
             self.close(retry=False)
         except Exception:
@@ -329,92 +331,94 @@ class SnowflakeConnection:
             return OCSPMode.FAIL_CLOSED
 
     @property
-    def session_id(self):
+    def session_id(self) -> int:
         return self._session_id
 
     @property
-    def user(self):
+    def user(self) -> str:
         return self._user
 
     @property
-    def host(self):
+    def host(self) -> str:
         return self._host
 
     @property
-    def port(self):
+    def port(self) -> int | str:  # TODO: shouldn't be a string
         return self._port
 
     @property
-    def region(self):
+    def region(self) -> str | None:
         warnings.warn(
             "Region has been deprecated and will be removed in the near future",
             PendingDeprecationWarning,
+            # Raise warning from where this property was called from
+            stacklevel=2,
         )
         return self._region
 
     @property
-    def proxy_host(self):
+    def proxy_host(self) -> str | None:
         return self._proxy_host
 
     @property
-    def proxy_port(self):
+    def proxy_port(self) -> str | None:
         return self._proxy_port
 
     @property
-    def proxy_user(self):
+    def proxy_user(self) -> str | None:
         return self._proxy_user
 
     @property
-    def proxy_password(self):
+    def proxy_password(self) -> str | None:
         return self._proxy_password
 
     @property
-    def account(self):
+    def account(self) -> str:
         return self._account
 
     @property
-    def database(self):
+    def database(self) -> str | None:
         return self._database
 
     @property
-    def schema(self):
+    def schema(self) -> str | None:
         return self._schema
 
     @property
-    def warehouse(self):
+    def warehouse(self) -> str | None:
         return self._warehouse
 
     @property
-    def role(self):
+    def role(self) -> str | None:
         return self._role
 
     @property
-    def login_timeout(self):
+    def login_timeout(self) -> int | None:
         return int(self._login_timeout) if self._login_timeout is not None else None
 
     @property
-    def network_timeout(self):
+    def network_timeout(self) -> int | None:
         return int(self._network_timeout) if self._network_timeout is not None else None
 
     @property
-    def client_session_keep_alive(self):
+    def client_session_keep_alive(self) -> bool | None:
         return self._client_session_keep_alive
 
     @client_session_keep_alive.setter
-    def client_session_keep_alive(self, value):
+    def client_session_keep_alive(self, value) -> None:
         self._client_session_keep_alive = value
 
     @property
-    def client_session_keep_alive_heartbeat_frequency(self):
+    def client_session_keep_alive_heartbeat_frequency(self) -> int | None:
         return self._client_session_keep_alive_heartbeat_frequency
 
     @client_session_keep_alive_heartbeat_frequency.setter
-    def client_session_keep_alive_heartbeat_frequency(self, value):
+    def client_session_keep_alive_heartbeat_frequency(self, value) -> None:
         self._client_session_keep_alive_heartbeat_frequency = value
         self._validate_client_session_keep_alive_heartbeat_frequency()
 
     @property
-    def client_prefetch_threads(self):
+    def client_prefetch_threads(self) -> int:
         return (
             self._client_prefetch_threads
             if self._client_prefetch_threads
@@ -422,38 +426,39 @@ class SnowflakeConnection:
         )
 
     @client_prefetch_threads.setter
-    def client_prefetch_threads(self, value):
+    def client_prefetch_threads(self, value) -> None:
         self._client_prefetch_threads = value
         self._validate_client_prefetch_threads()
 
     @property
-    def rest(self):
+    def rest(self) -> SnowflakeRestful | None:
         return self._rest
 
     @property
-    def application(self):
+    def application(self) -> str:
         return self._application
 
     @property
-    def errorhandler(self):
+    def errorhandler(self) -> Callable:  # TODO: callable args
         return self._errorhandler
 
     @errorhandler.setter
-    def errorhandler(self, value):
+    # Note: Callable doesn't implement operator|
+    def errorhandler(self, value: Callable | None) -> None:
         if value is None:
             raise ProgrammingError("None errorhandler is specified")
         self._errorhandler = value
 
     @property
-    def converter_class(self):
+    def converter_class(self) -> type[SnowflakeConverter]:
         return self._converter_class
 
     @property
-    def validate_default_parameters(self):
+    def validate_default_parameters(self) -> bool:
         return self._validate_default_parameters
 
     @property
-    def is_pyformat(self):
+    def is_pyformat(self) -> bool:
         return self._paramstyle in ("pyformat", "format")
 
     @property
@@ -461,35 +466,35 @@ class SnowflakeConnection:
         return self._consent_cache_id_token
 
     @property
-    def telemetry_enabled(self):
+    def telemetry_enabled(self) -> bool:
         return self._telemetry_enabled
 
     @telemetry_enabled.setter
-    def telemetry_enabled(self, value):
+    def telemetry_enabled(self, value) -> None:
         self._telemetry_enabled = True if value else False
 
     @property
-    def service_name(self):
+    def service_name(self) -> str | None:
         return self._service_name
 
     @service_name.setter
-    def service_name(self, value):
+    def service_name(self, value) -> None:
         self._service_name = value
 
     @property
-    def log_max_query_length(self):
+    def log_max_query_length(self) -> int:
         return self._log_max_query_length
 
     @property
-    def disable_request_pooling(self):
+    def disable_request_pooling(self) -> bool:
         return self._disable_request_pooling
 
     @disable_request_pooling.setter
-    def disable_request_pooling(self, value):
+    def disable_request_pooling(self, value) -> None:
         self._disable_request_pooling = True if value else False
 
     @property
-    def use_openssl_only(self):
+    def use_openssl_only(self) -> bool:
         return self._use_openssl_only
 
     @property
@@ -497,15 +502,15 @@ class SnowflakeConnection:
         return self._arrow_number_to_decimal
 
     @property
-    def enable_stage_s3_privatelink_for_us_east_1(self):
+    def enable_stage_s3_privatelink_for_us_east_1(self) -> bool:
         return self._enable_stage_s3_privatelink_for_us_east_1
 
     @enable_stage_s3_privatelink_for_us_east_1.setter
-    def enable_stage_s3_privatelink_for_us_east_1(self, value):
+    def enable_stage_s3_privatelink_for_us_east_1(self, value) -> None:
         self._enable_stage_s3_privatelink_for_us_east_1 = True if value else False
 
     @property
-    def enable_connection_diag(self):
+    def enable_connection_diag(self) -> bool:
         return self._enable_connection_diag
 
     @property
@@ -517,7 +522,7 @@ class SnowflakeConnection:
         return self._connection_diag_whitelist_path
 
     @arrow_number_to_decimal.setter
-    def arrow_number_to_decimal_setter(self, value: bool):
+    def arrow_number_to_decimal_setter(self, value: bool) -> None:
         self._arrow_number_to_decimal = value
 
     @property
@@ -531,7 +536,7 @@ class SnowflakeConnection:
         else:
             raise TypeError("auth_class must subclass AuthByPlugin")
 
-    def connect(self, **kwargs):
+    def connect(self, **kwargs) -> None:
         """Establishes connection to Snowflake."""
         logger.debug("connect")
         if len(kwargs) > 0:
@@ -565,7 +570,7 @@ class SnowflakeConnection:
         else:
             self.__open_connection()
 
-    def close(self, retry=True):
+    def close(self, retry: bool = True) -> None:
         """Closes the connection."""
         try:
             if not self.rest:
@@ -598,11 +603,11 @@ class SnowflakeConnection:
                 "Exception encountered in closing connection. ignoring...: %s", e
             )
 
-    def is_closed(self):
+    def is_closed(self) -> bool:
         """Checks whether the connection has been closed."""
         return self.rest is None
 
-    def autocommit(self, mode):
+    def autocommit(self, mode) -> None:
         """Sets autocommit mode to True, or False. Defaults to True."""
         if not self.rest:
             Error.errorhandler_wrapper(
@@ -633,11 +638,11 @@ class SnowflakeConnection:
                     "Autocommit feature is not enabled for this " "connection. Ignored"
                 )
 
-    def commit(self):
+    def commit(self) -> None:
         """Commits the current transaction."""
         self.cursor().execute("COMMIT")
 
-    def rollback(self):
+    def rollback(self) -> None:
         """Rolls back the current transaction."""
         self.cursor().execute("ROLLBACK")
 
@@ -693,7 +698,7 @@ class SnowflakeConnection:
             cur.execute(sql, _is_put_get=is_put_or_get, **kwargs)
             yield cur
 
-    def __set_error_attributes(self):
+    def __set_error_attributes(self) -> None:
         for m in [
             method for method in dir(errors) if callable(getattr(errors, method))
         ]:
@@ -702,7 +707,7 @@ class SnowflakeConnection:
             setattr(self, name, getattr(errors, m))
 
     @staticmethod
-    def setup_ocsp_privatelink(app, hostname):
+    def setup_ocsp_privatelink(app, hostname) -> None:
         SnowflakeConnection.OCSP_ENV_LOCK.acquire()
         ocsp_cache_server = f"http://ocsp.{hostname}/ocsp_response_cache.json"
         os.environ["SF_OCSP_RESPONSE_CACHE_SERVER_URL"] = ocsp_cache_server
@@ -801,7 +806,13 @@ class SnowflakeConnection:
                     port=self.port,
                 )
             else:
-                self.auth_class = AuthByIdToken(id_token=self._rest.id_token)
+                self.auth_class = AuthByIdToken(
+                    id_token=self._rest.id_token,
+                    application=self.application,
+                    protocol=self._protocol,
+                    host=self.host,
+                    port=self.port,
+                )
 
         elif self._authenticator == KEY_PAIR_AUTHENTICATOR:
             self.auth_class = AuthByKeyPair(private_key=self._private_key)
@@ -863,7 +874,9 @@ class SnowflakeConnection:
                     warnings.warn(
                         "'{}' is an unknown connection parameter{}".format(
                             name, f", did you mean '{guess}'?" if guess else ""
-                        )
+                        ),
+                        # Raise warning from where class was initiated
+                        stacklevel=4,
                     )
                 elif not isinstance(value, DEFAULT_CONFIGURATION[name][1]):
                     accepted_types = DEFAULT_CONFIGURATION[name][1]
@@ -876,7 +889,9 @@ class SnowflakeConnection:
                             if isinstance(accepted_types, tuple)
                             else accepted_types.__name__,
                             type(value).__name__,
-                        )
+                        ),
+                        # Raise warning from where class was initiated
+                        stacklevel=4,
                     )
             setattr(self, "_" + name, value)
 
@@ -1015,7 +1030,7 @@ class SnowflakeConnection:
         _no_results: bool = False,
         _update_current_object: bool = True,
         _no_retry: bool = False,
-    ):
+    ) -> dict[str, Any]:
         """Executes a query with a sequence counter."""
         logger.debug("_cmd_query")
         data = {
@@ -1078,14 +1093,19 @@ class SnowflakeConnection:
     def _reauthenticate(self):
         return self._auth_class.reauthenticate(conn=self)
 
-    def authenticate_with_retry(self, auth_instance):
+    def authenticate_with_retry(self, auth_instance) -> None:
         # make some changes if needed before real __authenticate
         try:
             self._authenticate(auth_instance)
         except ReauthenticationRequest as ex:
             # cached id_token expiration error, we have cleaned id_token and try to authenticate again
             logger.debug("ID token expired. Reauthenticating...: %s", ex)
-            self._authenticate(auth_instance)
+            if isinstance(auth_instance, AuthByIdToken):
+                # Note: SNOW-733835 IDToken auth needs to authenticate through
+                #  SSO if it has expired
+                self._reauthenticate()
+            else:
+                self._authenticate(auth_instance)
 
     def _authenticate(self, auth_instance: AuthByPlugin):
         auth_instance.prepare(
@@ -1323,7 +1343,7 @@ class SnowflakeConnection:
         _quote = self.converter.quote
         return _quote(escape(to_snowflake(param)))
 
-    def _cancel_query(self, sql, request_id):
+    def _cancel_query(self, sql: str, request_id: UUID) -> dict[str, bool | None]:
         """Cancels the query with the exact SQL query and requestId."""
         logger.debug("_cancel_query sql=[%s], request_id=[%s]", sql, request_id)
         url_parameters = {REQUEST_ID: str(uuid.uuid4())}
@@ -1336,19 +1356,19 @@ class SnowflakeConnection:
             },
         )
 
-    def _next_sequence_counter(self):
+    def _next_sequence_counter(self) -> int:
         """Gets next sequence counter. Used internally."""
         with self._lock_sequence_counter:
             self.sequence_counter += 1
             logger.debug("sequence counter: %s", self.sequence_counter)
             return self.sequence_counter
 
-    def _log_telemetry(self, telemetry_data):
+    def _log_telemetry(self, telemetry_data) -> None:
         """Logs data to telemetry."""
         if self.telemetry_enabled:
             self._telemetry.try_add_log_to_batch(telemetry_data)
 
-    def _add_heartbeat(self):
+    def _add_heartbeat(self) -> None:
         """Add an hourly heartbeat query in order to keep connection alive."""
         if not self.heartbeat_thread:
             self._validate_client_session_keep_alive_heartbeat_frequency()
@@ -1366,7 +1386,7 @@ class SnowflakeConnection:
             self.heartbeat_thread.start()
             logger.debug("started heartbeat")
 
-    def _cancel_heartbeat(self):
+    def _cancel_heartbeat(self) -> None:
         """Cancel a heartbeat thread."""
         if self.heartbeat_thread:
             self.heartbeat_thread.cancel()
@@ -1374,7 +1394,7 @@ class SnowflakeConnection:
             self.heartbeat_thread = None
             logger.debug("stopped heartbeat")
 
-    def _heartbeat_tick(self):
+    def _heartbeat_tick(self) -> None:
         """Execute a hearbeat if connection isn't closed yet."""
         if not self.is_closed():
             logger.debug("heartbeating!")
@@ -1398,7 +1418,7 @@ class SnowflakeConnection:
         )
         return self.client_session_keep_alive_heartbeat_frequency
 
-    def _validate_client_prefetch_threads(self):
+    def _validate_client_prefetch_threads(self) -> int:
         if self.client_prefetch_threads <= 0:
             self._client_prefetch_threads = 1
         elif self.client_prefetch_threads > MAX_CLIENT_PREFETCH_THREADS:
@@ -1440,7 +1460,7 @@ class SnowflakeConnection:
             elif PARAMETER_ENABLE_STAGE_S3_PRIVATELINK_FOR_US_EAST_1 == name:
                 self.enable_stage_s3_privatelink_for_us_east_1 = value
 
-    def _format_query_for_log(self, query):
+    def _format_query_for_log(self, query: str) -> str:
         ret = " ".join(line.strip() for line in query.split("\n"))
         return (
             ret
@@ -1448,11 +1468,16 @@ class SnowflakeConnection:
             else ret[0 : self.log_max_query_length] + "..."
         )
 
-    def __enter__(self):
+    def __enter__(self) -> SnowflakeConnection:
         """Context manager."""
         return self
 
-    def __exit__(self, exc_type, exc_val, exc_tb):
+    def __exit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_val: BaseException | None,
+        exc_tb: TracebackType | None,
+    ) -> None:
         """Context manager with commit or rollback teardown."""
         if not self._session_parameters.get("AUTOCOMMIT", False):
             # Either AUTOCOMMIT is turned off, or is not set so we default to old behavior
