@@ -1,15 +1,18 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2012-2021 Snowflake Computing Inc. All rights reserved.
 #
 
+from __future__ import annotations
+
+from typing import Any
+
 from .converter import SnowflakeConverter
 
 
 class SnowflakeNoConverterToPython(SnowflakeConverter):
-    def __init__(self, **kwargs):
-        super(SnowflakeNoConverterToPython, self).__init__(**kwargs)
+    def __init__(self, **kwargs) -> None:
+        super().__init__(**kwargs)
 
-    def to_python_method(self, type_name, column):
+    def to_python_method(self, type_name: str, column: dict[str, Any]) -> None:
         return None
