@@ -10,7 +10,7 @@ import os
 import re
 import traceback
 from logging import getLogger
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 from .compat import BASE_EXCEPTION_CLASS
 from .secret_detector import SecretDetector
@@ -38,16 +38,18 @@ class Error(BASE_EXCEPTION_CLASS):
         errno: int | None = None,
         sqlstate: str | None = None,
         sfqid: str | None = None,
+        query: str | None = None,
         done_format_msg: bool | None = None,
         connection: SnowflakeConnection | None = None,
         cursor: SnowflakeCursor | None = None,
-    ):
+    ) -> None:
         super().__init__(msg)
         self.msg = msg
         self.raw_msg = msg
         self.errno = errno or -1
         self.sqlstate = sqlstate or "n/a"
         self.sfqid = sfqid
+        self.query = query
 
         if self.msg:
             # TODO: If there's a message then check to see if errno (and maybe sqlstate)
@@ -80,10 +82,10 @@ class Error(BASE_EXCEPTION_CLASS):
         self.telemetry_traceback = self.generate_telemetry_stacktrace()
         self.exception_telemetry(msg, cursor, connection)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.__str__()
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.msg
 
     @staticmethod
@@ -117,9 +119,11 @@ class Error(BASE_EXCEPTION_CLASS):
         else:
             return None
 
-    def generate_telemetry_exception_data(self) -> dict[str, str]:
+    def generate_telemetry_exception_data(
+        self,
+    ) -> dict[str, tuple[bool, str, str] | str]:
         """Generate the data to send through telemetry."""
-        telemetry_data_dict = {
+        telemetry_data_dict: dict[str, tuple[bool, str, str] | str] = {
             TelemetryField.KEY_STACKTRACE.value: SecretDetector.mask_secrets(
                 self.telemetry_traceback
             )
@@ -139,7 +143,7 @@ class Error(BASE_EXCEPTION_CLASS):
     def send_exception_telemetry(
         self,
         connection: SnowflakeConnection | None,
-        telemetry_data: dict[str, str],
+        telemetry_data: dict[str, Any],
     ) -> None:
         """Send telemetry data by in-band telemetry if it is enabled, otherwise send through out-of-band telemetry."""
 
@@ -179,9 +183,15 @@ class Error(BASE_EXCEPTION_CLASS):
         try:
             telemetry_data_dict = self.generate_telemetry_exception_data()
             if cursor is not None:
-                self.send_exception_telemetry(cursor.connection, telemetry_data_dict)
+                self.send_exception_telemetry(
+                    cursor.connection,
+                    telemetry_data_dict,
+                )
             elif connection is not None:
-                self.send_exception_telemetry(connection, telemetry_data_dict)
+                self.send_exception_telemetry(
+                    connection,
+                    telemetry_data_dict,
+                )
             else:
                 self.send_exception_telemetry(None, telemetry_data_dict)
         except Exception:
@@ -206,12 +216,17 @@ class Error(BASE_EXCEPTION_CLASS):
         Raises:
             A Snowflake error.
         """
+        errno = error_value.get("errno")
+        done_format_msg = error_value.get("done_format_msg")
         raise error_class(
             msg=error_value.get("msg"),
-            errno=error_value.get("errno"),
+            errno=None if errno is None else int(errno),
             sqlstate=error_value.get("sqlstate"),
             sfqid=error_value.get("sfqid"),
-            done_format_msg=error_value.get("done_format_msg"),
+            query=error_value.get("query"),
+            done_format_msg=(
+                None if done_format_msg is None else bool(done_format_msg)
+            ),
             connection=connection,
             cursor=cursor,
         )
@@ -254,7 +269,7 @@ class Error(BASE_EXCEPTION_CLASS):
         connection: SnowflakeConnection | None,
         cursor: SnowflakeCursor | None,
         error_class: type[Error] | type[Exception],
-        error_value: dict[str, str | bool | int],
+        error_value: dict[str, Any],
     ) -> None:
         """Error handler wrapper that calls the errorhandler method.
 
@@ -404,7 +419,7 @@ class NotSupportedError(DatabaseError):
     """Exception for errors when an unsupported database feature was used."""
 
     # Not supported errors do not have any PII in their
-    def telemetry_msg(self):
+    def telemetry_msg(self) -> str:
         return self.msg
 
 
@@ -412,7 +427,7 @@ class RevocationCheckError(OperationalError):
     """Exception for errors during certificate revocation check."""
 
     # We already send OCSP exception events
-    def exception_telemetry(self, msg, cursor, connection):
+    def exception_telemetry(self, msg, cursor, connection) -> None:
         pass
 
 
@@ -420,7 +435,7 @@ class RevocationCheckError(OperationalError):
 class InternalServerError(Error):
     """Exception for 500 HTTP code for retry."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         Error.__init__(
             self,
             msg=kwargs.get("msg") or "HTTP 500: Internal Server Error",
@@ -433,7 +448,7 @@ class InternalServerError(Error):
 class ServiceUnavailableError(Error):
     """Exception for 503 HTTP code for retry."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         Error.__init__(
             self,
             msg=kwargs.get("msg") or "HTTP 503: Service Unavailable",
@@ -446,7 +461,7 @@ class ServiceUnavailableError(Error):
 class GatewayTimeoutError(Error):
     """Exception for 504 HTTP error for retry."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         Error.__init__(
             self,
             msg=kwargs.get("msg") or "HTTP 504: Gateway Timeout",
@@ -459,7 +474,7 @@ class GatewayTimeoutError(Error):
 class ForbiddenError(Error):
     """Exception for 403 HTTP error for retry."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         Error.__init__(
             self,
             msg=kwargs.get("msg") or "HTTP 403: Forbidden",
@@ -472,7 +487,7 @@ class ForbiddenError(Error):
 class RequestTimeoutError(Error):
     """Exception for 408 HTTP error for retry."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         Error.__init__(
             self,
             msg=kwargs.get("msg") or "HTTP 408: Request Timeout",
@@ -485,7 +500,7 @@ class RequestTimeoutError(Error):
 class BadRequest(Error):
     """Exception for 400 HTTP error for retry."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         Error.__init__(
             self,
             msg=kwargs.get("msg") or "HTTP 400: Bad Request",
@@ -498,7 +513,7 @@ class BadRequest(Error):
 class BadGatewayError(Error):
     """Exception for 502 HTTP error for retry."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         Error.__init__(
             self,
             msg=kwargs.get("msg") or "HTTP 502: Bad Gateway",
@@ -511,7 +526,7 @@ class BadGatewayError(Error):
 class MethodNotAllowed(Error):
     """Exception for 405 HTTP error for retry."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         Error.__init__(
             self,
             msg=kwargs.get("msg") or "HTTP 405: Method not allowed",
@@ -524,7 +539,7 @@ class MethodNotAllowed(Error):
 class OtherHTTPRetryableError(Error):
     """Exception for other HTTP error for retry."""
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         code = kwargs.get("code", "n/a")
         Error.__init__(
             self,
@@ -538,7 +553,7 @@ class OtherHTTPRetryableError(Error):
 class MissingDependencyError(Error):
     """Exception for missing extras dependencies."""
 
-    def __init__(self, dependency: str):
+    def __init__(self, dependency: str) -> None:
         super().__init__(msg=f"Missing optional dependency: {dependency}")
 
 
