@@ -66,7 +66,7 @@ INJECT_WAIT_IN_PUT = 0
 logger = getLogger(__name__)
 
 
-def result_text_column_desc(name):
+def result_text_column_desc(name: str) -> dict[str, Any]:
     return {
         "name": name,
         "type": "text",
@@ -77,7 +77,7 @@ def result_text_column_desc(name):
     }
 
 
-def result_fixed_column_desc(name):
+def result_fixed_column_desc(name: str) -> dict[str, Any]:
     return {
         "name": name,
         "type": "fixed",
@@ -195,7 +195,7 @@ class SnowflakeProgressPercentage:
         filesize: int | float,
         output_stream: IO | None = sys.stdout,
         show_progress_bar: bool | None = True,
-    ):
+    ) -> None:
         last_pound_char = filename.rfind("#")
         if last_pound_char < 0:
             last_pound_char = len(filename)
@@ -219,7 +219,7 @@ class SnowflakeS3ProgressPercentage(SnowflakeProgressPercentage):
         filesize: int | float,
         output_stream: IO | None = sys.stdout,
         show_progress_bar: bool | None = True,
-    ):
+    ) -> None:
         super().__init__(
             filename,
             filesize,
@@ -227,7 +227,7 @@ class SnowflakeS3ProgressPercentage(SnowflakeProgressPercentage):
             show_progress_bar=show_progress_bar,
         )
 
-    def __call__(self, bytes_amount: int):
+    def __call__(self, bytes_amount: int) -> None:
         with self._lock:
             if self._output_stream:
                 self._seen_so_far += bytes_amount
@@ -250,7 +250,7 @@ class SnowflakeAzureProgressPercentage(SnowflakeProgressPercentage):
         filesize: int | float,
         output_stream: IO | None = sys.stdout,
         show_progress_bar: bool | None = True,
-    ):
+    ) -> None:
         super().__init__(
             filename,
             filesize,
@@ -258,7 +258,7 @@ class SnowflakeAzureProgressPercentage(SnowflakeProgressPercentage):
             show_progress_bar=show_progress_bar,
         )
 
-    def __call__(self, current: int):
+    def __call__(self, current: int) -> None:
         with self._lock:
             if self._output_stream:
                 self._seen_so_far = current
@@ -280,14 +280,14 @@ class StorageCredential:
         credentials: dict[str, Any],
         connection: SnowflakeConnection,
         command: str,
-    ):
+    ) -> None:
         self.creds = credentials
         self.timestamp = time()
         self.lock = threading.Lock()
         self.connection = connection
         self._command = command
 
-    def update(self, cur_timestamp):
+    def update(self, cur_timestamp) -> None:
         with self.lock:
             if cur_timestamp < self.timestamp:
                 return
@@ -324,7 +324,7 @@ class SnowflakeFileTransferAgent:
         multipart_threshold: int | None = None,
         source_from_stream: IO[bytes] | None = None,
         use_s3_regional_url: bool = False,
-    ):
+    ) -> None:
         self._cursor = cursor
         self._command = command
         self._ret = ret
@@ -423,7 +423,7 @@ class SnowflakeFileTransferAgent:
         is_upload = self._command_type == CMD_TYPE_UPLOAD
         exception_caught_in_callback: Exception | None = None
 
-        def notify_file_completed():
+        def notify_file_completed() -> None:
             # Increment the number of completed files, then notify the main thread.
             with cv_main_thread:
                 transfer_metadata.num_files_completed += 1
@@ -434,7 +434,7 @@ class SnowflakeFileTransferAgent:
             result: Any,
             file_meta: SnowflakeFileMeta,
             done_client: SnowflakeStorageClient,
-        ):
+        ) -> None:
             if not success:
                 logger.debug(f"Failed to prepare {done_client.meta.name}.")
                 if is_upload:
@@ -491,7 +491,7 @@ class SnowflakeFileTransferAgent:
             file_meta: SnowflakeFileMeta,
             done_client: SnowflakeStorageClient,
             chunk_id: int,
-        ):
+        ) -> None:
             # Note: chunk_id is 0 based while num_of_chunks is count
             logger.debug(
                 f"Chunk {chunk_id}/{done_client.num_of_chunks} of file {done_client.meta.name} reached callback"
@@ -538,7 +538,7 @@ class SnowflakeFileTransferAgent:
             result: Any,
             file_meta: SnowflakeFileMeta,
             done_client: SnowflakeStorageClient,
-        ):
+        ) -> None:
             logger.debug(f"File {done_client.meta.name} reached postprocess callback")
 
             with done_client.lock:
@@ -668,7 +668,7 @@ class SnowflakeFileTransferAgent:
             client = self._create_file_transfer_client(self._file_metadata[0])
             self._use_accelerate_endpoint = client.transfer_accelerate_config()
 
-    def result(self):
+    def result(self) -> dict[str, Any]:
         converter_class = self._cursor._connection.converter_class
         rowset = []
         if self._command_type == CMD_TYPE_UPLOAD:
@@ -792,7 +792,7 @@ class SnowflakeFileTransferAgent:
                 "rowset": sorted(rowset),
             }
 
-    def _expand_filenames(self, locations):
+    def _expand_filenames(self, locations: list[str]) -> list[str]:
         canonical_locations = []
         for file_name in locations:
             if self._command_type == CMD_TYPE_UPLOAD:
