@@ -8,7 +8,12 @@ from __future__ import annotations
 import os
 
 
-def set_proxies(proxy_host, proxy_port, proxy_user=None, proxy_password=None):
+def set_proxies(
+    proxy_host: str | None,
+    proxy_port: str | None,
+    proxy_user: str | None = None,
+    proxy_password: str | None = None,
+) -> dict[str, str] | None:
     """Sets proxy dict for requests."""
     PREFIX_HTTP = "http://"
     PREFIX_HTTPS = "https://"
