@@ -24,7 +24,7 @@ from .network import (
     raise_failed_request_error,
     raise_okta_unauthorized_error,
 )
-from .options import installed_pandas, pandas
+from .options import installed_pandas
 from .options import pyarrow as pa
 from .secret_detector import SecretDetector
 from .time_util import DecorrelateJitterBackoff, TimerContextManager
@@ -36,18 +36,14 @@ MAX_DOWNLOAD_RETRY = 10
 DOWNLOAD_TIMEOUT = 7  # seconds
 
 if TYPE_CHECKING:  # pragma: no cover
+    from pandas import DataFrame
+    from pyarrow import DataType, Table
+
     from .connection import SnowflakeConnection
     from .converter import SnowflakeConverterType
     from .cursor import ResultMetadata, SnowflakeCursor
     from .vendored.requests import Response
 
-    if installed_pandas:
-        DataType = pa.DataType
-        Table = pa.Table
-    else:
-        DataType = None
-        Table = None
-
 
 # emtpy pyarrow type array corresponding to FIELD_TYPES
 FIELD_TYPE_TO_PA_TYPE: list[DataType] = []
@@ -96,9 +92,7 @@ def create_batches_from_response(
             )
             return type_name, python_method
 
-        column_converters: list[tuple[str, SnowflakeConverterType]] = [
-            col_to_converter(c) for c in rowtypes
-        ]
+        column_converters = [col_to_converter(c) for c in rowtypes]
     else:
         rowset_b64 = data.get("rowsetBase64")
         arrow_context = ArrowConverterContext(cursor._connection._session_parameters)
@@ -217,7 +211,7 @@ class ResultBatch(abc.ABC):
         remote_chunk_info: RemoteChunkInfo | None,
         schema: Sequence[ResultMetadata],
         use_dict_result: bool,
-    ):
+    ) -> None:
         self.rowcount = rowcount
         self._chunk_headers = chunk_headers
         self._remote_chunk_info = remote_chunk_info
@@ -343,7 +337,7 @@ class ResultBatch(abc.ABC):
         Iterator[dict | Exception]
         | Iterator[tuple | Exception]
         | Iterator[Table]
-        | Iterator[pandas.DataFrame]
+        | Iterator[DataFrame]
     ):
         """Downloads the data from from blob storage that this ResultChunk points at.
 
@@ -372,7 +366,7 @@ class ResultBatch(abc.ABC):
             )
 
     @abc.abstractmethod
-    def to_pandas(self) -> pandas.DataFrame:
+    def to_pandas(self) -> DataFrame:
         raise NotImplementedError()
 
     @abc.abstractmethod
@@ -389,7 +383,7 @@ class JSONResultBatch(ResultBatch):
         schema: Sequence[ResultMetadata],
         column_converters: Sequence[tuple[str, SnowflakeConverterType]],
         use_dict_result: bool,
-    ):
+    ) -> None:
         super().__init__(
             rowcount,
             chunk_headers,
@@ -417,9 +411,7 @@ class JSONResultBatch(ResultBatch):
             column_converters,
             use_dict_result,
         )
-        new_chunk._data: (
-            list[dict | Exception] | list[tuple | Exception]
-        ) = new_chunk._parse(data)
+        new_chunk._data = new_chunk._parse(data)
         return new_chunk
 
     def _load(self, response: Response) -> list:
@@ -534,7 +526,7 @@ class ArrowResultBatch(ResultBatch):
         numpy: bool,
         schema: Sequence[ResultMetadata],
         number_to_decimal: bool,
-    ):
+    ) -> None:
         super().__init__(
             rowcount,
             chunk_headers,
@@ -664,7 +656,7 @@ class ArrowResultBatch(ResultBatch):
 
     def to_pandas(
         self, connection: SnowflakeConnection | None = None, **kwargs
-    ) -> pandas.DataFrame:
+    ) -> DataFrame:
         """Returns this batch as a pandas DataFrame"""
         self._check_can_use_pandas()
         table = self.to_arrow(connection=connection)
@@ -672,7 +664,7 @@ class ArrowResultBatch(ResultBatch):
 
     def _get_pandas_iter(
         self, connection: SnowflakeConnection | None = None, **kwargs
-    ) -> Iterator[pandas.DataFrame]:
+    ) -> Iterator[DataFrame]:
         """An iterator for this batch which yields a pandas DataFrame"""
         iterator_data = []
         dataframe = self.to_pandas(connection=connection, **kwargs)
@@ -686,7 +678,7 @@ class ArrowResultBatch(ResultBatch):
         Iterator[dict | Exception]
         | Iterator[tuple | Exception]
         | Iterator[Table]
-        | Iterator[pandas.DataFrame]
+        | Iterator[DataFrame]
     ):
         """The interface used by ResultSet to create an iterator for this ResultBatch."""
         iter_unit: IterUnit = kwargs.pop("iter_unit", IterUnit.ROW_UNIT)
