@@ -6,12 +6,16 @@ from __future__ import annotations
 
 import logging
 import warnings
+from collections.abc import Mapping
+from typing import Any
 
 
-def getSnowLogger(name=None, extra=None):
-    if name:
-        logger = logging.getLogger(name)
-        return SnowLogger(logger, extra)
+def getSnowLogger(
+    name: str,
+    extra: Mapping[str, object] | None = None,
+) -> SnowLogger:
+    logger = logging.getLogger(name)
+    return SnowLogger(logger, extra)  # type:ignore[arg-type]
 
 
 class SnowLogger(logging.LoggerAdapter):
@@ -22,16 +26,44 @@ class SnowLogger(logging.LoggerAdapter):
     used in Cython code (.pyx).
     """
 
-    def debug(self, msg, path_name=None, func_name=None, *args, **kwargs):
+    def debug(  # type: ignore[override]
+        self,
+        msg: str,
+        path_name: str | None = None,
+        func_name: str | None = None,
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
         self.log(logging.DEBUG, msg, path_name, func_name, *args, **kwargs)
 
-    def info(self, msg, path_name=None, func_name=None, *args, **kwargs):
+    def info(  # type: ignore[override]
+        self,
+        msg: str,
+        path_name: str | None = None,
+        func_name: str | None = None,
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
         self.log(logging.INFO, msg, path_name, func_name, *args, **kwargs)
 
-    def warning(self, msg, path_name=None, func_name=None, *args, **kwargs):
+    def warning(  # type: ignore[override]
+        self,
+        msg: str,
+        path_name: str | None = None,
+        func_name: str | None = None,
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
         self.log(logging.WARNING, msg, path_name, func_name, *args, **kwargs)
 
-    def warn(self, msg, path_name=None, func_name=None, *args, **kwargs):
+    def warn(  # type: ignore[override]
+        self,
+        msg: str,
+        path_name: str | None = None,
+        func_name: str | None = None,
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
         warnings.warn(
             "The 'warn' method is deprecated, " "use 'warning' instead",
             DeprecationWarning,
@@ -39,30 +71,50 @@ class SnowLogger(logging.LoggerAdapter):
         )
         self.warning(msg, path_name, func_name, *args, **kwargs)
 
-    def error(self, msg, path_name=None, func_name=None, *args, **kwargs):
+    def error(  # type: ignore[override]
+        self,
+        msg: str,
+        path_name: str | None = None,
+        func_name: str | None = None,
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
         self.log(logging.ERROR, msg, path_name, func_name, *args, **kwargs)
 
-    def exception(
-        self, msg, path_name=None, func_name=None, *args, exc_info=True, **kwargs
-    ):
+    def exception(  # type: ignore[override]
+        self,
+        msg: str,
+        path_name: str | None = None,
+        func_name: str | None = None,
+        *args: Any,
+        exc_info: bool = True,
+        **kwargs: Any,
+    ) -> None:
         """Convenience method for logging an ERROR with exception information."""
         self.error(msg, path_name, func_name, *args, exc_info=exc_info, **kwargs)
 
-    def critical(self, msg, path_name=None, func_name=None, *args, **kwargs):
+    def critical(  # type: ignore[override]
+        self,
+        msg: str,
+        path_name: str | None = None,
+        func_name: str | None = None,
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
         self.log(logging.CRITICAL, msg, path_name, func_name, *args, **kwargs)
 
     fatal = critical
 
-    def log(
+    def log(  # type: ignore[override]
         self,
         level: int,
         msg: str,
         path_name: str | None = None,
         func_name: str | None = None,
         line_num: int = 0,
-        *args,
-        **kwargs,
-    ):
+        *args: Any,
+        **kwargs: Any,
+    ) -> None:
         """Generalized log method of SnowLogger wrapper.
 
         Args:
