@@ -1,9 +1,10 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
-# Copyright (c) 2012-2021 Snowflake Computing Inc. All right reserved.
+# Copyright (c) 2012-2021 Snowflake Computing Inc. All rights reserved.
 #
 
+from __future__ import annotations
+
 import time
 from os import path
 from time import gmtime, strftime
@@ -15,10 +16,10 @@ from snowflake.connector.ocsp_asn1crypto import SnowflakeOCSPAsn1Crypto as SFOCS
 from snowflake.connector.ssl_wrap_socket import _openssl_connect
 
 
-def main():
+def main() -> None:
     """Internal Tool: OCSP response dumper."""
 
-    def help():
+    def help() -> None:
         print("Dump OCSP Response for the URL. ")
         print(
             """
@@ -38,7 +39,7 @@ Usage: {} <url> [<url> ...]
     dump_ocsp_response(urls, output_filename=None)
 
 
-def dump_good_status(current_time, single_response):
+def dump_good_status(current_time, single_response) -> None:
     print("This Update: {}".format(single_response["this_update"].native))
     print("Next Update: {}".format(single_response["next_update"].native))
     this_update = (
@@ -60,7 +61,7 @@ def dump_good_status(current_time, single_response):
         print(SFOCSP._validity_error_message(current_time, this_update, next_update))
 
 
-def dump_revoked_status(single_response):
+def dump_revoked_status(single_response) -> None:
     revoked_info = single_response["cert_status"]
     revocation_time = revoked_info.native["revocation_time"]
     revocation_reason = revoked_info.native["revocation_reason"]
@@ -69,7 +70,7 @@ def dump_revoked_status(single_response):
             revocation_time.strftime(SFOCSP.OUTPUT_TIMESTAMP_FORMAT)
         )
     )
-    print("Revoked Reason: {}".format(revocation_reason))
+    print(f"Revoked Reason: {revocation_reason}")
 
 
 def dump_ocsp_response(urls, output_filename):
@@ -83,7 +84,7 @@ def dump_ocsp_response(urls, output_filename):
         connection = _openssl_connect(hostname, port)
         cert_data = ocsp.extract_certificate_chain(connection)
         current_time = int(time.time())
-        print("Target URL: {}".format(url))
+        print(f"Target URL: {url}")
         print(
             "Current Time: {}".format(strftime("%Y%m%d%H%M%SZ", gmtime(current_time)))
         )
@@ -94,13 +95,13 @@ def dump_ocsp_response(urls, output_filename):
             )
             ocsp_response = asn1crypto_ocsp.OCSPResponse.load(ocsp_response_der)
             print("------------------------------------------------------------")
-            print("Subject Name: {}".format(subject.subject.native))
-            print("Issuer Name: {}".format(issuer.subject.native))
-            print("OCSP URI: {}".format(subject.ocsp_urls))
-            print("CRL URI: {}".format(subject.crl_distribution_points[0].native))
-            print("Issuer Name Hash: {}".format(subject.issuer.sha1))
-            print("Issuer Key Hash: {}".format(issuer.public_key.sha1))
-            print("Serial Number: {}".format(subject.serial_number))
+            print(f"Subject Name: {subject.subject.native}")
+            print(f"Issuer Name: {issuer.subject.native}")
+            print(f"OCSP URI: {subject.ocsp_urls}")
+            print(f"CRL URI: {subject.crl_distribution_points[0].native}")
+            print(f"Issuer Name Hash: {subject.issuer.sha1}")
+            print(f"Issuer Key Hash: {issuer.public_key.sha1}")
+            print(f"Serial Number: {subject.serial_number}")
             print("Response Status: {}".format(ocsp_response["response_status"].native))
             basic_ocsp_response = ocsp_response.basic_ocsp_response
             tbs_response_data = basic_ocsp_response["tbs_response_data"]
